pub struct FitRunV1 {Show 15 fields
pub schema_version: String,
pub fit_run_id: FitRunId,
pub mechanism_bundle_id: MechanismBundleId,
pub theory_version_id: TheoryVersionId,
pub simulation_contract_id: SimulationContractId,
pub fit_score: f64,
pub disposition: FitDisposition,
pub advisory_only: bool,
pub degraded: bool,
pub refuter_ready: bool,
pub stability_clear: bool,
pub theory_refuter_suite_id: TheoryRefuterSuiteId,
pub rollout_stability_report_id: RolloutStabilityReportId,
pub notes: Vec<String>,
pub generated_at: String,
}Fields
schema_version: Stringfit_run_id: FitRunIdmechanism_bundle_id: MechanismBundleIdtheory_version_id: TheoryVersionIdsimulation_contract_id: SimulationContractIdfit_score: f64disposition: FitDispositionadvisory_only: booldegraded: boolrefuter_ready: boolstability_clear: booltheory_refuter_suite_id: TheoryRefuterSuiteIdrollout_stability_report_id: RolloutStabilityReportIdnotes: Vec<String>generated_at: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for FitRunV1
impl<'de> Deserialize<'de> for FitRunV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FitRunV1
impl JsonSchema for FitRunV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for FitRunV1