pub struct HypothesisLibraryV1 {
pub schema_version: String,
pub hypothesis_library_id: HypothesisLibraryId,
pub hypothesis_refs: Vec<String>,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringhypothesis_library_id: HypothesisLibraryIdhypothesis_refs: Vec<String>publication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for HypothesisLibraryV1
impl Clone for HypothesisLibraryV1
Sourcefn clone(&self) -> HypothesisLibraryV1
fn clone(&self) -> HypothesisLibraryV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HypothesisLibraryV1
impl Debug for HypothesisLibraryV1
Sourceimpl<'de> Deserialize<'de> for HypothesisLibraryV1
impl<'de> Deserialize<'de> for HypothesisLibraryV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HypothesisLibraryV1
Sourceimpl JsonSchema for HypothesisLibraryV1
impl JsonSchema for HypothesisLibraryV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HypothesisLibraryV1
impl PartialEq for HypothesisLibraryV1
Sourcefn eq(&self, other: &HypothesisLibraryV1) -> bool
fn eq(&self, other: &HypothesisLibraryV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for HypothesisLibraryV1
impl Serialize for HypothesisLibraryV1
impl StructuralPartialEq for HypothesisLibraryV1