pub struct RolloutStabilityReportV1 {
pub schema_version: String,
pub rollout_stability_report_id: RolloutStabilityReportId,
pub theory_version_id: TheoryVersionId,
pub invariance_summary: String,
pub advisory_only: bool,
pub locally_reviewable: bool,
pub blocking_findings: Vec<String>,
}Fields
schema_version: Stringrollout_stability_report_id: RolloutStabilityReportIdtheory_version_id: TheoryVersionIdinvariance_summary: Stringadvisory_only: boollocally_reviewable: boolblocking_findings: Vec<String>Trait Implementations
Sourceimpl Clone for RolloutStabilityReportV1
impl Clone for RolloutStabilityReportV1
Sourcefn clone(&self) -> RolloutStabilityReportV1
fn clone(&self) -> RolloutStabilityReportV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RolloutStabilityReportV1
impl Debug for RolloutStabilityReportV1
Sourceimpl<'de> Deserialize<'de> for RolloutStabilityReportV1
impl<'de> Deserialize<'de> for RolloutStabilityReportV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RolloutStabilityReportV1
Sourceimpl JsonSchema for RolloutStabilityReportV1
impl JsonSchema for RolloutStabilityReportV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RolloutStabilityReportV1
impl PartialEq for RolloutStabilityReportV1
Sourcefn eq(&self, other: &RolloutStabilityReportV1) -> bool
fn eq(&self, other: &RolloutStabilityReportV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RolloutStabilityReportV1
impl Serialize for RolloutStabilityReportV1
impl StructuralPartialEq for RolloutStabilityReportV1