pub struct SimulationContractV1 {
pub schema_version: String,
pub simulation_contract_id: SimulationContractId,
pub mechanism_bundle_id: MechanismBundleId,
pub target_outcome: String,
pub required_inputs: Vec<String>,
pub advisory_only: bool,
}Fields
schema_version: Stringsimulation_contract_id: SimulationContractIdmechanism_bundle_id: MechanismBundleIdtarget_outcome: Stringrequired_inputs: Vec<String>advisory_only: boolTrait Implementations
Sourceimpl Clone for SimulationContractV1
impl Clone for SimulationContractV1
Sourcefn clone(&self) -> SimulationContractV1
fn clone(&self) -> SimulationContractV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimulationContractV1
impl Debug for SimulationContractV1
Sourceimpl<'de> Deserialize<'de> for SimulationContractV1
impl<'de> Deserialize<'de> for SimulationContractV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SimulationContractV1
Sourceimpl JsonSchema for SimulationContractV1
impl JsonSchema for SimulationContractV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SimulationContractV1
impl PartialEq for SimulationContractV1
Sourcefn eq(&self, other: &SimulationContractV1) -> bool
fn eq(&self, other: &SimulationContractV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SimulationContractV1
impl Serialize for SimulationContractV1
impl StructuralPartialEq for SimulationContractV1