pub struct TheoryLibraryV1 {
pub schema_version: String,
pub theory_library_id: TheoryLibraryId,
pub theory_version_ids: Vec<TheoryVersionId>,
pub canonical_owner: String,
pub publication_status: SurfaceStatus,
}Fields
schema_version: Stringtheory_library_id: TheoryLibraryIdtheory_version_ids: Vec<TheoryVersionId>canonical_owner: Stringpublication_status: SurfaceStatusTrait Implementations
Sourceimpl Clone for TheoryLibraryV1
impl Clone for TheoryLibraryV1
Sourcefn clone(&self) -> TheoryLibraryV1
fn clone(&self) -> TheoryLibraryV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TheoryLibraryV1
impl Debug for TheoryLibraryV1
Sourceimpl<'de> Deserialize<'de> for TheoryLibraryV1
impl<'de> Deserialize<'de> for TheoryLibraryV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TheoryLibraryV1
Sourceimpl JsonSchema for TheoryLibraryV1
impl JsonSchema for TheoryLibraryV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TheoryLibraryV1
impl PartialEq for TheoryLibraryV1
Sourcefn eq(&self, other: &TheoryLibraryV1) -> bool
fn eq(&self, other: &TheoryLibraryV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TheoryLibraryV1
impl Serialize for TheoryLibraryV1
impl StructuralPartialEq for TheoryLibraryV1