pub struct TheoryVersionV1 {
pub schema_version: String,
pub theory_version_id: TheoryVersionId,
pub mechanism_bundle_id: MechanismBundleId,
pub theory_name: String,
pub semantic_version: String,
pub advisory_only: bool,
}Fields
schema_version: Stringtheory_version_id: TheoryVersionIdmechanism_bundle_id: MechanismBundleIdtheory_name: Stringsemantic_version: Stringadvisory_only: boolTrait Implementations
Sourceimpl Clone for TheoryVersionV1
impl Clone for TheoryVersionV1
Sourcefn clone(&self) -> TheoryVersionV1
fn clone(&self) -> TheoryVersionV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TheoryVersionV1
impl Debug for TheoryVersionV1
Sourceimpl<'de> Deserialize<'de> for TheoryVersionV1
impl<'de> Deserialize<'de> for TheoryVersionV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TheoryVersionV1
Sourceimpl JsonSchema for TheoryVersionV1
impl JsonSchema for TheoryVersionV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TheoryVersionV1
impl PartialEq for TheoryVersionV1
Sourcefn eq(&self, other: &TheoryVersionV1) -> bool
fn eq(&self, other: &TheoryVersionV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for TheoryVersionV1
impl Serialize for TheoryVersionV1
impl StructuralPartialEq for TheoryVersionV1